Struct Frame
pub struct Frame { /* private fields */ }Expand description
A container widget that groups related content with a border and optional title.
The frame displays a border around its content and supports an optional title that is positioned to intersect the frame’s border, similar to an HTML fieldset.
Examples
Frame::new(cx, |cx| {
Label::new(cx, "Frame content").hoverable(false);
}).title_position(FrameTitlePosition::TopCenter);Implementations